@@ -6,11 +6,13 @@ import re
 import os
 import logging
 import fnmatch
+from stat import S_IRUSR, S_IWUSR, S_IRGRP, S_IWGRP, S_IROTH, S_IWOTH
 from .exceptions import FileNotFoundError
 
 MAXLEN = 120
 ILEGAL = r'<>:"/\|?*'
 LOGGER = logging.getLogger(__name__)
+MODE666 = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH
 
 
 class File(object):
@@ -24,9 +26,10 @@ class File(object):
         self.path = os.path.dirname(fp) or os.getcwd()
         self.basename = os.path.basename(fp)
         self.name, self.ext = os.path.splitext(self.basename)
+        self.writable = os.access(fp, os.W_OK)
 
     def siblings(self):
-        """Collect files and folders in the same folder."""
+        """Collect files and directories in the same directory."""
         return [f for f in os.listdir(self.path) if f != self.basename]
 
     @staticmethod
@@ -82,6 +85,11 @@ class File(object):
                         new_basename)
             return True
 
+    @staticmethod
+    def uxchmod(fp, mode=MODE666):
+        """Change the mode of the file (default is 0666)."""
+        return os.chmod(fp, mode)
+
 
 def cwdfiles(pattern='*'):
     """List the files in current directory that match a given pattern."""
